summaryrefslogtreecommitdiffstats
path: root/telecomm
diff options
context:
space:
mode:
authorTyler Gunn <tgunn@google.com>2015-07-31 09:02:32 -0700
committerTyler Gunn <tgunn@google.com>2015-07-31 09:02:32 -0700
commita21b2e30b246b152b3b3692384de534ade2f3485 (patch)
treea13af078fdf4dfc0373934ac69cf1e1b72a57655 /telecomm
parent9bc9469807703757f50fffd34ed6b3f6183cdc6e (diff)
parentd0694da4fb85bb01e7c0ea7989a78a0e635453ac (diff)
downloadframeworks_base-a21b2e30b246b152b3b3692384de534ade2f3485.zip
frameworks_base-a21b2e30b246b152b3b3692384de534ade2f3485.tar.gz
frameworks_base-a21b2e30b246b152b3b3692384de534ade2f3485.tar.bz2
resolved conflicts for merge of d0694da4 to mnc-dr-dev
Change-Id: Ifd2636d0e1b7eae15d412cfa0a948a572c905b3a
Diffstat (limited to 'telecomm')
-rw-r--r--telecomm/java/android/telecom/Connection.java29
-rw-r--r--telecomm/java/android/telecom/TelecomManager.java7
2 files changed, 28 insertions, 8 deletions
diff --git a/telecomm/java/android/telecom/TelecomManager.java b/telecomm/java/android/telecom/TelecomManager.java
index 3b59f27..067e734 100644
--- a/telecomm/java/android/telecom/TelecomManager.java
+++ b/telecomm/java/android/telecom/TelecomManager.java
@@ -177,6 +177,13 @@ public class TelecomManager {
"android.telecom.extra.PHONE_ACCOUNT_HANDLE";
/**
+ * Optional extra for {@link android.content.Intent#ACTION_CALL} containing a string call
+ * subject which will be associated with an outgoing call. Should only be specified if the
+ * {@link PhoneAccount} supports the capability {@link PhoneAccount#CAPABILITY_CALL_SUBJECT}.
+ */
+ public static final String EXTRA_CALL_SUBJECT = "android.telecom.extra.CALL_SUBJECT";
+
+ /**
* The extra used by a {@link ConnectionService} to provide the handle of the caller that
* has initiated a new incoming call.
*/
diff --git a/telecomm/java/android/telecom/Connection.java b/telecomm/java/android/telecom/Connection.java
index 26477ce..706dcfb 100644
--- a/telecomm/java/android/telecom/Connection.java
+++ b/telecomm/java/android/telecom/Connection.java
@@ -253,20 +253,33 @@ public abstract class Connection extends Conferenceable {
//**********************************************************************************************
/**
- * Call extras key to pack/unpack call history info.
- * The value for this key should be an ArrayList of Strings.
+ * TODO: Remove this -- retained so the build won't break. However, future work will remove it.
* @hide
*/
public static final String EXTRA_CALL_HISTORY_INFO = "android.telecom.EXTRA_CALL_HISTORY_INFO";
/**
- * Connection {@link #mExtras} key used to store a child number associated with the current
- * connection. Used to communicate to the user interface that the connection was received via
- * a child address (in telephony phone number) associated with the {@link PhoneAccount}'s
- * primary address.
- * @hide
+ * Connection extra key used to store the last forwarded number associated with the current
+ * connection. Used to communicate to the user interface that the connection was forwarded via
+ * the specified number.
+ */
+ public static final String EXTRA_LAST_FORWARDED_NUMBER =
+ "android.telecom.extra.LAST_FORWARDED_NUMBER";
+
+ /**
+ * Connection extra key used to store a child number associated with the current connection.
+ * Used to communicate to the user interface that the connection was received via
+ * a child address (i.e. phone number) associated with the {@link PhoneAccount}'s primary
+ * address.
+ */
+ public static final String EXTRA_CHILD_ADDRESS = "android.telecom.extra.CHILD_ADDRESS";
+
+ /**
+ * Connection extra key used to store the subject for an incoming call. The user interface can
+ * query this extra and display its contents for incoming calls. Will only be used if the
+ * {@link PhoneAccount} supports the capability {@link PhoneAccount#CAPABILITY_CALL_SUBJECT}.
*/
- public static final String EXTRA_CHILD_ADDRESS = "android.telecom.EXTRA_CHILD_ADDRESS";
+ public static final String EXTRA_CALL_SUBJECT = "android.telecom.extra.CALL_SUBJECT";
// Flag controlling whether PII is emitted into the logs
private static final boolean PII_DEBUG = Log.isLoggable(android.util.Log.DEBUG);